@@ -1,14 +1,19 @@
 #' @title Summarise scores as produced by [score()]
 #'
-#' @description Summarise scores as produced by [score()]-
+#' @description Summarise scores as produced by [score()]
 #'
 #' @inheritParams pairwise_comparison
 #' @inheritParams score
 #' @param by character vector with column names to summarise scores by. Default
 #' is `NULL`, meaning that the only summary that takes is place is summarising
-#' over quantiles (in case of quantile-based forecasts), such that there is one
-#' score per forecast as defined by the unit of a single forecast (rather than
-#' one score for every quantile).
+#' over samples or quantiles (in case of quantile-based forecasts), such that
+#' there is one score per forecast as defined by the *unit of a single forecast*
+#' (rather than one score for every sample or quantile).
+#' The *unit of a single forecast* is determined by the columns present in the
+#' input data that do not correspond to a metric produced by [score()], which
+#' indicate indicate a grouping of forecasts (for example there may be one
+#' forecast per day, location and model). Adding additional, unrelated, columns
+#' may alter results in an unpredictable way.
 #' @param fun a function used for summarising scores. Default is `mean`.
 #' @param relative_skill logical, whether or not to compute relative
 #' performance between models based on pairwise comparisons.
@@ -17,10 +22,12 @@
 #' the computation of relative skill, see [pairwise_comparison()].
 #' Relative skill will be calculated for the aggregation level specified in
 #' `by`.
-#' @param metric character with the name of the metric for which
+#' @param relative_skill_metric character with the name of the metric for which
 #' a relative skill shall be computed. If equal to 'auto' (the default), then
 #' this will be either interval score, CRPS or Brier score (depending on which
 #' of these is available in the input data)
+#' @param metric  `r lifecycle::badge("deprecated")` Deprecated in 1.1.0. Use
+#' `relative_skill_metric` instead.
 #' @param baseline character string with the name of a model. If a baseline is
 #' given, then a scaled relative skill with respect to the baseline will be
 #' returned. By default (`NULL`), relative skill will not be scaled with
@@ -29,8 +36,13 @@
 #' provided to `fun`. For more information see the documentation of the
 #' respective function.
 #' @examples
+#' data.table::setDTthreads(1) # only needed to avoid issues on CRAN
 #' library(magrittr) # pipe operator
 #'
+#' scores <- score(example_continuous)
+#' summarise_scores(scores)
+#'
+#'
 #' # summarise over samples or quantiles to get one score per forecast
 #' scores <- score(example_quantile)
 #' summarise_scores(scores)
@@ -64,13 +76,20 @@ summarise_scores <- function(scores,
                              by = NULL,
                              fun = mean,
                              relative_skill = FALSE,
-                             metric = "auto",
+                             relative_skill_metric = "auto",
+                             metric = deprecated(),
                              baseline = NULL,
                              ...) {
-
+  if (lifecycle::is_present(metric)) {
+    lifecycle::deprecate_warn(
+      "1.1.0", "summarise_scores(metric)",
+      "summarise_scores(relative_skill_metric)"
+    )
+  }
   # preparations ---------------------------------------------------------------
   # get unit of a single forecast
-  forecast_unit <- get_forecast_unit(scores)
+  prediction_type <- get_prediction_type(scores)
+  forecast_unit <- get_forecast_unit(scores, prediction_type = prediction_type)
 
   # if by is not provided, set to the unit of a single forecast
   if (is.null(by)) {
@@ -83,7 +102,7 @@ summarise_scores <- function(scores,
     by = by,
     relative_skill = relative_skill,
     baseline = baseline,
-    metric = metric
+    metric = relative_skill_metric
   )
 
   # get all available metrics to determine names of columns to summarise over
@@ -101,7 +120,7 @@ summarise_scores <- function(scores,
   if (relative_skill) {
     pairwise <- pairwise_comparison(
       scores = scores,
-      metric = metric,
+      metric = relative_skill_metric,
       baseline = baseline,
       by = by
     )
@@ -131,10 +150,10 @@ summarise_scores <- function(scores,
   # remove unnecessary columns -------------------------------------------------
   # if neither quantile nor range are in by, remove coverage and
   # quantile_coverage because averaging does not make sense
-  if (!("range" %in% by) & ("coverage" %in% colnames(scores))) {
+  if (!("range" %in% by) && ("coverage" %in% colnames(scores))) {
     scores[, c("coverage") := NULL]
   }
-  if (!("quantile" %in% by) & "quantile_coverage" %in% names(scores)) {
+  if (!("quantile" %in% by) && "quantile_coverage" %in% names(scores)) {
     scores[, c("quantile_coverage") := NULL]
   }
 
